@@ -22,7 +22,7 @@
    into a PhysicalCardSet.
    """
 
-from sutekh.core.CardSetHolder import CardSetHolder
+from sutekh.core.CardSetHolder import CachedCardSetHolder
 from sutekh.core.CardLookup import DEFAULT_LOOKUP
 from sqlobject import sqlhub
 # pylint: disable-msg=E0611, F0401
@@ -41,12 +41,12 @@ class PhysicalCardSetParser(object):
        """
     def __init__(self):
         self.aSupportedVersions = ['1.2', '1.1', '1.0']
-        self.oCS = CardSetHolder()
+        self.oCS = CachedCardSetHolder()
         self.oTree = None
 
     def _convert_tree(self):
         """Convert the ElementTree into a CardSetHolder"""
-        self.oCS = CardSetHolder()
+        self.oCS = CachedCardSetHolder()
         oRoot = self.oTree.getroot()
         if oRoot.tag != 'physicalcardset':
             raise RuntimeError("Not a Physical Card Set list")
@@ -81,7 +81,7 @@ class PhysicalCardSetParser(object):
                     sExpansionName = None
                 self.oCS.add(iCount, sName, sExpansionName)
 
-    def _commit_tree(self, oCardLookup):
+    def _commit_tree(self, oCardLookup, dLookupCache):
         """Commit the tree to the database.
 
            We use the card set holder, so it calls the appropriate card lookup
@@ -89,33 +89,37 @@ class PhysicalCardSetParser(object):
            """
         oOldConn = sqlhub.processConnection
         sqlhub.processConnection = oOldConn.transaction()
-        self.oCS.create_pcs(oCardLookup)
+        self.oCS.create_pcs(oCardLookup, dLookupCache)
         sqlhub.processConnection.commit()
         sqlhub.processConnection = oOldConn
 
-    def parse(self, fIn, oCardLookup=DEFAULT_LOOKUP, bIgnoreWarnings=True):
-        """Read the file fIn into the database."""
-        self.oTree = parse(fIn)
-        self._convert_tree()
-        self._commit_tree(oCardLookup)
-        if not bIgnoreWarnings:
-            return self.oCS.get_warnings()
-        else:
-            return []
-
-    def parse_string(self, sIn, oCardLookup=DEFAULT_LOOKUP,
-            bIgnoreWarnings=True):
-        """Read the string sIn into the database."""
-        self.oTree = ElementTree(fromstring(sIn))
-        self._convert_tree()
-        self._commit_tree(oCardLookup)
-        if not bIgnoreWarnings:
-            return self.oCS.get_warnings()
-        else:
-            return []
-
     def string_to_holder(self, sIn):
         """Parse the string into a Card Set Holder without commiting it"""
         self.oTree = ElementTree(fromstring(sIn))
         self._convert_tree()
         return self.oCS
+
+    # pylint: disable-msg=W0102
+    # W0102 - {} is the right thing here
+    def parse(self, fIn, oCardLookup=DEFAULT_LOOKUP, bIgnoreWarnings=True,
+            dLookupCache={}):
+        """Read the file fIn into the database."""
+        self.oTree = parse(fIn)
+        self._convert_tree()
+        self._commit_tree(oCardLookup, dLookupCache)
+        if not bIgnoreWarnings:
+            return self.oCS.get_warnings()
+        else:
+            return []
+
+    def parse_string(self, sIn, oCardLookup=DEFAULT_LOOKUP,
+            bIgnoreWarnings=True, dLookupCache={}):
+        """Read the string sIn into the database."""
+        self.oTree = ElementTree(fromstring(sIn))
+        self._convert_tree()
+        self._commit_tree(oCardLookup, dLookupCache)
+        if not bIgnoreWarnings:
+            return self.oCS.get_warnings()
+        else:
+            return []
+
