@@ -13,6 +13,7 @@ from sutekh.core.SutekhObjects import AbstractCard, IAbstractCard, \
         MapPhysicalCardToPhysicalCardSet
 from sutekh.core import Filters
 from sqlobject import SQLObjectNotFound
+from sutekh.core.CardLookup import best_guess_filter
 import unittest
 
 class FilterTests(SutekhTest):
@@ -110,8 +111,9 @@ class FilterTests(SutekhTest):
             (Filters.ExpansionRarityFilter(('Sabbat', 'Rare')),
                 [u"Ablative Skin"]),
             (Filters.ExpansionRarityFilter(('Blood Shadowed Court',
-                'BSC')), [u"Alfred Benezri", u"Anastasz di Zagreb",
-                    u"Gracis Nostinus", u"Yvette, The Hopeless"]),
+                'BSC')), [u"Alan Sovereign", u"Alfred Benezri",
+                    u"Anastasz di Zagreb", u"Gracis Nostinus",
+                    u"Yvette, The Hopeless"]),
             (Filters.MultiExpansionRarityFilter([('Third', 'Uncommon'),
                 ('Jyhad', 'Rare')]), [u"Aaron's Feeding Razor", u"Abbot"]),
             (Filters.DisciplineLevelFilter(('cel', 'superior')),
@@ -174,15 +176,44 @@ class FilterTests(SutekhTest):
                 [u"Aaron Duggan, Cameron's Toady", u"Abombwe"]),
             (Filters.CostFilter(5), [u"AK-47"]),
             (Filters.MultiCostFilter([2, 5]), [u".44 Magnum", u"AK-47"]),
+            (Filters.MultiCostFilter([0]), [u'Aabbt Kindred',
+                u'Aaron Bathurst', u"Aaron Duggan, Cameron's Toady",
+                u'Abandoning the Flesh', u'Abbot', u'Abd al-Rashid',
+                u'Abdelsobek', u'Abebe', u'Abjure', u'Ablative Skin',
+                u'Abombwe', u'Aeron', u'Akram', u'Alan Sovereign',
+                u'Alan Sovereign (Advanced)', u'Alexandra', u'Alfred Benezri',
+                u'Ambrogino Giovanni', u'Amisa', u'Anastasz di Zagreb',
+                u'Angelica, The Canonicus', u'Anna "Dictatrix11" Suljic',
+                u'Anson', u'Bronwen', u'Cedric', u'Cesewayo',
+                u'Earl "Shaka74" Deams', u'Gracis Nostinus',
+                u'Inez "Nurse216" Villagrande', u'Kabede Maru',
+                u'Kemintiri (Advanced)', u'L\xe1z\xe1r Dobrescu',
+                u"Predator's Communion", u'Sha-Ennu',
+                u'Yvette, The Hopeless']),
+            (Filters.MultiCostFilter([0, 5]), [u"AK-47", u'Aabbt Kindred',
+                u'Aaron Bathurst', u"Aaron Duggan, Cameron's Toady",
+                u'Abandoning the Flesh', u'Abbot', u'Abd al-Rashid',
+                u'Abdelsobek', u'Abebe', u'Abjure', u'Ablative Skin',
+                u'Abombwe', u'Aeron', u'Akram', u'Alan Sovereign',
+                u'Alan Sovereign (Advanced)', u'Alexandra', u'Alfred Benezri',
+                u'Ambrogino Giovanni', u'Amisa', u'Anastasz di Zagreb',
+                u'Angelica, The Canonicus', u'Anna "Dictatrix11" Suljic',
+                u'Anson', u'Bronwen', u'Cedric', u'Cesewayo',
+                u'Earl "Shaka74" Deams', u'Gracis Nostinus',
+                u'Inez "Nurse216" Villagrande', u'Kabede Maru',
+                u'Kemintiri (Advanced)', u'L\xe1z\xe1r Dobrescu',
+                u"Predator's Communion", u'Sha-Ennu',
+                u'Yvette, The Hopeless']),
             (Filters.LifeFilter(6), [u'Anna "Dictatrix11" Suljic',
                 u'Earl "Shaka74" Deams']),
             (Filters.MultiLifeFilter([3, 6]), [u'Anna "Dictatrix11" Suljic',
                 u'Earl "Shaka74" Deams', u'Inez "Nurse216" Villagrande']),
             (Filters.CostTypeFilter('Pool'), [u".44 Magnum", u"AK-47",
-                u"Aaron's Feeding Razor"]),
+                u"Aaron's Feeding Razor", u"The Path of Blood"]),
             (Filters.CostTypeFilter('Blood'), [u"Aire of Elation"]),
             (Filters.MultiCostTypeFilter(['Pool', 'Blood']), [u".44 Magnum",
-                u"AK-47", u"Aaron's Feeding Razor", u"Aire of Elation"]),
+                u"AK-47", u"Aaron's Feeding Razor", u"Aire of Elation",
+                U"The Path of Blood"]),
             (Filters.LifeFilter(4), []),
             (Filters.MultiLifeFilter([4, 5]), []),
 
@@ -206,7 +237,8 @@ class FilterTests(SutekhTest):
                 'Vampire'])), [u"Abandoning the Flesh", u"Abbot", u"Abjure",
                     u"Ablative Skin", u"Abombwe", u"Aire of Elation",
                     u'Anna "Dictatrix11" Suljic', u'Earl "Shaka74" Deams',
-                    u'Inez "Nurse216" Villagrande', u"Predator's Communion"]),
+                    u'Inez "Nurse216" Villagrande', u"Predator's Communion",
+                    u"The Path of Blood"]),
         ]
 
         aPhysicalTests = [self._physical_test(tTest) for tTest in aTests]
@@ -265,7 +297,8 @@ class FilterTests(SutekhTest):
                 (Filters.MultiPhysicalExpansionFilter(['LoB', 'LotN']),
                     ['Abombwe','.44 Magnum', 'Abebe', 'AK-47', 'Abdelsobek',
                         u"Cedric", u"Cesewayo", u"Kabede Maru",
-                        u"Predator's Communion"], ['LoB', 'LotN']),
+                        u"Predator's Communion", u"The Path of Blood"],
+                    ['LoB', 'LotN']),
                 (Filters.MultiPhysicalExpansionFilter(
                     ['  Unspecified Expansion', 'VTES']),
                     self.aExpectedCards,
@@ -433,5 +466,24 @@ class FilterTests(SutekhTest):
                     " failed. %s != %s." % (oFullFilter, aCSCards,
                         aExpectedCards))
 
+    def test_best_guess_filter(self):
+        """Test the best guess filter"""
+        # This seems the best fit, to include it with the other filter tests
+        aTests = [('Sha-Ennu', [u'Sha-Ennu']),
+                ('She-Ennu', [u'Sha-Ennu']),
+                ('Saa-Ennu', [u'Sha-Ennu']),
+                ('47', [u'AK-47']),
+                ('4', [u'.44 Magnum', u'AK-47', u'Earl "Shaka74" Deams']),
+                ('Alex', [u'Alexandra']),
+                ('Raven', []),
+                ('Path of Blood, The', [u'The Path of Blood']),
+                ]
+        for sGuess, aExpectedNames in aTests:
+            oFilter = best_guess_filter(sGuess)
+            aNames = [x.name for x in oFilter.select(AbstractCard)]
+            self.assertEqual(aNames, aExpectedNames,
+                    '%s != expected %s for guess %s' % (aNames, aExpectedNames,
+                        sGuess))
+
 if __name__ == "__main__":
     unittest.main()
